package com.ozs.web.controller.shotschedule;

import com.ozs.common.core.domain.entity.SysDictData;
import com.ozs.common.utils.DictUtils;
import com.ozs.system.service.ISysDictDataService;
import com.ozs.system.service.ISysDictTypeService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Configuration;
import org.springframework.scheduling.annotation.Async;
import org.springframework.scheduling.annotation.EnableAsync;
import org.springframework.scheduling.annotation.EnableScheduling;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.scheduling.concurrent.ThreadPoolTaskExecutor;
import org.springframework.util.CollectionUtils;

import javax.annotation.Resource;
import java.util.List;
import java.util.Objects;

/**
 * @author wyy
 * @subject
 * @creat 2024/3/1
 */
@Configuration
@EnableScheduling
@EnableAsync
@Slf4j
public class ShotPictureExecutors {
    @Autowired
    private TaskService taskService; //任务
    @Value("${shot.storeAddress}")
    private String storeAddress;
    @Resource
    private ThreadPoolTaskExecutor threadPoolTaskExecutor;
    @Autowired
    private ISysDictTypeService iSysDictTypeService;

    /**
     * 处理非预警摄像头截图
     */
    @Async
    @Scheduled(fixedRate = 60000)
    public void handleNormalPicture() {

        try {
            List<SysDictData> dataList = DictUtils.getDictCache("shot_switch");
            if(CollectionUtils.isEmpty(dataList)){
                dataList = iSysDictTypeService.selectDictDataByType("shot_switch");
                DictUtils.setDictCache("shot_switch",dataList);
            }
            if(Boolean.parseBoolean(dataList.get(0).getDictLabel())){
                this.threadPoolTaskExecutor.execute(taskService::getNormalPicture);
            }
        } catch (Exception e) {
            e.getMessage();
            log.error("正常摄像机截图定时任务失败",e);
        }
    }

    /**
     * 处理预警摄像头截图
     */
    @Scheduled(fixedRate = 500)
    public void handleAlarmPicture() {
        try {
            List<SysDictData> dataList = DictUtils.getDictCache("shot_switch");
            if(CollectionUtils.isEmpty(dataList)){
                dataList = iSysDictTypeService.selectDictDataByType("shot_switch");
                DictUtils.setDictCache("shot_switch",dataList);
            }
            if(Boolean.parseBoolean(dataList.get(0).getDictLabel())){
                this.threadPoolTaskExecutor.execute(taskService::getAlarmPicture);
            }
        } catch (Exception e) {
            e.getMessage();
            log.error("报警摄像机截图定时任务失败",e);
        }
    }
}
